mkdir /tmp/logs/
mkdir /tmp/logs/aco_server
mkdir /tmp/logs/aco_web
mkdir /tmp/logs/mongo
mkdir /tmp/logs/mysql
mkdir /tmp/logs/nginx
mkdir /tmp/logs/thread_dump
mkdir /tmp/logs/cli_logs
mkdir /tmp/logs/top

cp /opt/akkadian/aco-server/aco-server.log /tmp/logs/aco_server/
cp /opt/akkadian/aco-server/aco-server.*.log /tmp/logs/aco_server/
cp /opt/tomcat/logs/* /tmp/logs/aco_web/
cp /opt/akkadian/data/log/mongodb/* /tmp/logs/mongo/
cp /var/log/mysqld.log /tmp/logs/mysql/
cp /var/log/nginx/error.log /tmp/logs/nginx/
cp /var/log/nginx/access.log /tmp/logs/nginx/
tar -zcvf /tmp/logs/thread_dump.tar.gz /home/akkadianuser/*.hprof 
cp /var/www/product_update/update.log /tmp/logs/cli_logs/
cp /home/akkadianuser/logs/cli_installation.log /tmp/logs/cli_logs/
cp /home/akkadianuser/logs/aco_installation.log /tmp/logs/cli_logs/
cp /home/akkadianuser/logs/ha_init_process.log /tmp/logs/cli_logs/
cp /home/akkadianuser/logs/replica_init_process.log /tmp/logs/cli_logs/
cp /home/akkadianuser/logs/replica_init_process_aco.log /tmp/logs/cli_logs/
cp /home/akkadianuser/logs/mongo_recovery.log /tmp/logs/cli_logs/

aco_version=$(sh /home/akkadianuser/scripts/get_ACOSERVER_version.sh)
acoweb_version=$(sh /home/akkadianuser/scripts/get_ACOWEB_version.sh)
cli_version=$(sh /home/akkadianuser/scripts/get_cli_version.sh)

#This is valid only version 4.0 of cli
is_ha=$(sh /home/akkadianuser/scripts/replication/mongo/is_mongo_replication_set_in_config_file.sh)
nodes=$(head -n 1 /home/akkadianuser/load_balancer.config)
current_hostname=$(sudo hostname)
isServerReachable="False"

for j in $nodes
do
    if [[ "$j" != "$current_hostname" ]]; then
        isServerReachable=$(sh /home/akkadianuser/scripts/is_server_reachable_telnet.sh $j 22)
    fi
done
top -b -n 10 > /tmp/logs/top/top_status
master=$(sh /home/akkadianuser/scripts/get_master.sh)

mysql_status=$(systemctl status mysqld)
mongo_status=$(systemctl status mongodb)

events_mongodb_web=$(sh /home/akkadianuser/scripts/get_console_events_web.sh)
events_mongodb_server=$(sh /home/akkadianuser/scripts/get_console_events.sh)
number_devices=$(mysql --defaults-extra-file=/home/akkadianuser/.my_aco.cnf -u root fp -e "select count(*) as number_devices from Device;")
number_directories=$(mysql --defaults-extra-file=/home/akkadianuser/.my_aco.cnf -u root fp -e "select count(*) as number_directories from DirectoryEntry;")
number_providers=$(mysql --defaults-extra-file=/home/akkadianuser/.my_aco.cnf -u root fp -e  "select count(*) as number_providers from Provider;")
number_distinct_providers=$(mysql --defaults-extra-file=/home/akkadianuser/.my_aco.cnf -u root fp -e "select distinct count(*) as number_unique_providers from Provider;")
number_logged_operators=$(mysql --defaults-extra-file=/home/akkadianuser/.my_aco.cnf -u root fp -e "select count(*) as number_users_log from users")
number_tenants=$(sudo mongo --authenticationDatabase admin -u mongoDBuser -p 'X46kTVmongo' AcoServer --eval "db.getCollection('Tenant').find({}).count()")


jtapi_version=$(unzip -q -c /opt/tomcat/lib/jtapi-9.1.jar META-INF/MANIFEST.MF | grep Implementation-Version: | awk '{print "" $2}')

printf "
******* Current version ******* \n
aco_version=$aco_version\n
acoweb_version=$acoweb_version\n
cli_version=$cli_version\n

******* HA Status ***********\n
is_ha_running=$is_ha\n
nodes=$nodes\n
current_hostname=$current_hostname\n
is_the_other_node_reachable=$isServerReachable\n
master=$master\n

******* mysql status *******\n
\n
$mysql_status
\n
****** mongo status ********\n
$mongo_status
\n

***** environment values *****\n
events web\n
$events_mongodb_web\n

events console\n
$events_mongodb_server\n

$number_devices\n
$number_directories\n
$number_providers\n
$number_distinct_providers\n
$number_logged_operators\n

number_tenants\n
$number_tenants\n

jtapi_rsion=$jtapi_version\n" > /tmp/logs/environment_summary.log

#snapshot cpu, memory.
now=`date +"%Y-%m-%d%H%M%S"`
tar -zcvf /tmp/logs.tar.gz /tmp/logs/*

if [[ ! -d /opt/akkadian/aco-server/wwwroot/public-logs ]]; then
  mkdir /opt/akkadian/aco-server/wwwroot/public-logs
fi

cp /tmp/logs.tar.gz /opt/akkadian/aco-server/wwwroot/public-logs/logs-${now}.tar.gz

rm -Rf /tmp/logs.tar.gz
rm -Rf /tmp/logs
rm -Rf /tmp/*.hprof
rm -Rf /home/akkadianuser/*.hprof 

rm -Rf /opt/tomcat/logs/acow-webapp.*.log
rm -Rf /opt/tomcat/logs/acow-webapp-*.log
rm -Rf /opt/tomcat/logs/catalina.*.log
rm -Rf /opt/tomcat/logs/hibernate.log
rm -Rf /opt/tomcat/logs/host-manager.*.log
rm -Rf /opt/tomcat/logs/localhost.*.log
rm -Rf /opt/tomcat/logs/manager.*.log

rm -Rf /opt/akkadian/aco-server/aco-server.*.log

#rm -Rf /opt/akkadian/data/log/mongodb/*
#rm -Rf /var/log/mysqld.log
